@@ -407,7 +407,7 @@ test_that("wb_dims() corner cases work", {
   got <- wb_dims(rows = c(1, 30), cols = c(2, 4)) # expect B1,D1,B30,D30
   expect_equal(exp, got)
 
-  exp <- "B2,D2,B1,D1"
+  exp <- "B2:B1,D2:D1"
   got <- wb_dims(rows = c(2, 1), cols = c(2, 4))  # expect B2,D2,B1,D1
   expect_equal(exp, got)
 
@@ -787,3 +787,50 @@ test_that("wb_dims does not try to validate column names", {
   expect_equal(exp, got)
 
 })
+
+test_that("wb_dims handles decreasing consecutive columns and rows", {
+
+  exp <- "A3:A1,B3:B1,C3:C1,H3:H1,I3:I1,J3:J1"
+  got <- wb_dims(rows = 3:1, cols = c(1:3, 8:10))
+  expect_equal(exp, got)
+
+  exp <- "A3:A1,B3:B1,C3:C1,J3:J1,I3:I1,H3:H1"
+  got <- wb_dims(rows = 3:1, cols = c(1:3, 10:8))
+  expect_equal(exp, got)
+
+  exp <- "C3:C1,B3:B1,A3:A1,J3:J1,I3:I1,H3:H1"
+  got <- wb_dims(rows = 3:1, cols = c(3:1, 10:8))
+  expect_equal(exp, got)
+
+})
+
+test_that("dims are the same", {
+  blank  <- dims_to_dataframe("C3:A1", fill = FALSE)
+  filled <- dims_to_dataframe("C3:A1", fill = TRUE)
+  expect_equal(dimnames(blank), dimnames(filled))
+
+  one <- dims_to_dataframe("A1:C3", fill = TRUE)
+  two <- dims_to_dataframe("C3:A1", fill = TRUE)
+
+  expect_equal(
+    unname(unlist(one)),
+    rev(unname(unlist(two)))
+  )
+
+  # this is a probably exclusively internal handler that can be used to create
+  # non consecutive dims for wb_add_fill(). At the moment it does not appear to
+  # be required to keep the column and row ordering of each of the pieces.
+  # This might also be non trivial for something like "B3:A1,A5:C6"
+  # (is it up/down and left/right?)
+  exp <- dims_to_dataframe("B1:C2,B5:C8", fill = FALSE)
+  got <- dims_to_dataframe("C1:B2,C5:B8", fill = FALSE)
+  expect_equal(exp, got)
+
+})
+
+test_that("reverse rows and cols work", {
+  expect_equal("A1:C3", wb_dims(rows = 1:3, cols = 1:3))
+  expect_equal("C3:A1", wb_dims(rows = 3:1, cols = 3:1))
+  expect_equal("C1:A3", wb_dims(rows = 1:3, cols = 3:1))
+  expect_equal("A3:C1", wb_dims(rows = 3:1, cols = 1:3))
+})
